"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.listFolder = void 0;
/*
 * @vuepress
 * ---
 * headline: lib/list-folder.ts
 * ---
 */
const micromatch_1 = __importDefault(require("micromatch"));
const promises_1 = __importDefault(require("node:fs/promises"));
const node_path_1 = __importDefault(require("node:path"));
/**
 * Recursively traverse folders and return exluded files, a file list and a file tree.
 * @param {string} srcPath path to source dir
 * @param {array} exclude exluded file patter list
 * @param {array} include included file patter list
 * @param {string} mainPath path to hold source dir
 * @param {object} tree tree array
 * @returns {object} paths array, tree, excluded array
 */
const listFolder = (srcPath, exclude, include, mainPath, tree = []) => __awaiter(void 0, void 0, void 0, function* () {
    if (!Boolean(exclude) || !Array.isArray(exclude)) {
        exclude = [];
    }
    if (!Boolean(include) || !Array.isArray(include)) {
        include = [];
    }
    exclude = exclude.filter(Boolean);
    include = include.filter(Boolean);
    const paths = [];
    const excluded = [];
    const dirs = srcPath
        ? yield promises_1.default.readdir(srcPath, {
            withFileTypes: true
        })
        : [];
    for (const dirent of dirs) {
        const filePath = node_path_1.default.join(srcPath, dirent.name);
        const isDir = dirent.isDirectory();
        const ext = node_path_1.default.extname(filePath);
        let name = node_path_1.default.basename(filePath).replace(ext, '');
        const folder = filePath.replace(name, '').replace(ext, '');
        if (name.endsWith('index')) {
            name = srcPath.replace(/\//g, '-') + '-' + name;
        }
        const file = Object.assign({ isDir,
            name, path: filePath }, (!isDir ? { ext, folder } : {}));
        // skip readmes as they are automatically resolved
        if (name.toLowerCase() === 'readme')
            continue;
        const baseSrc = mainPath || srcPath;
        if (micromatch_1.default.every(node_path_1.default.join(srcPath.replace(baseSrc, ''), dirent.name), [...include, ...exclude.map((e) => '!' + e)]) ||
            isDir) {
            let treeEntry = {
                name
            };
            if (isDir) {
                treeEntry.children = [];
                paths.push(...(yield (0, exports.listFolder)(filePath, exclude, include, baseSrc, treeEntry.children)).paths);
            }
            else {
                treeEntry = Object.assign(Object.assign({}, treeEntry), { path: `/${name}`, fullPath: node_path_1.default.join(srcPath, name), ext });
            }
            tree.push(treeEntry);
            paths.push(file);
        }
        else {
            excluded.push(file);
        }
    }
    return { paths, tree, excluded };
});
exports.listFolder = listFolder;
