"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateVueSidebar = void 0;
/*
 * @vuepress
 * ---
 * headline: lib/vue-sidebar.ts
 * ---
 */
const node_fs_1 = __importDefault(require("node:fs"));
const node_path_1 = require("node:path");
/**
 * Runs through the given tree structure and creates a vuepress config
 * @param {object} data Information to build config
 * @param {array} data.fileTree tree structure
 * @param {string} data.codeFolder ./code/ folder
 * @param {string} data.srcFolder ./src/ folder
 * @param {string} data.docsFolder ./documentation/ folder
 * @param {string} data.title title string
 * @returns {object} returns the vuepress menu structure
 */
const generateVueSidebar = ({ fileTree, codeFolder, srcFolder, docsFolder, title }) => {
    let rootFiles = [{ link: `/${codeFolder}/`, text: '::vuepress-jsdoc-title::' }];
    rootFiles = rootFiles.concat(fileTree.filter((file) => !file.children).map((file) => `/${(0, node_path_1.join)(codeFolder, file.name)}`));
    const rootFolder = fileTree.filter((file) => file.children && file.children.length > 0);
    const buildChildren = (children, name, depth) => {
        let newChildren = [];
        for (const child of children) {
            if (child.children && child.children.length > 0) {
                newChildren = newChildren.concat(buildChildren(child.children, child.name, depth + 1));
            }
            else if (child.fullPath) {
                const path = child.fullPath.replace(srcFolder, '');
                if (node_fs_1.default.existsSync(`${(0, node_path_1.join)(docsFolder, path)}.md`)) {
                    newChildren.push(`/${(0, node_path_1.join)(codeFolder, path)}`);
                }
            }
        }
        return newChildren;
    };
    const tree = rootFolder.map((folder) => ({
        text: folder.name,
        collapsable: false,
        children: buildChildren(folder.children, folder.name, 0)
    }));
    return {
        [`/${codeFolder}/`]: [
            {
                text: title,
                collapsable: false,
                children: rootFiles
            }
        ].concat(tree)
    };
};
exports.generateVueSidebar = generateVueSidebar;
